aboutsummaryrefslogtreecommitdiff
path: root/contrib/epee
diff options
context:
space:
mode:
authorJethro Grassie <jtg@xtrabass.com>2019-01-21 11:50:03 -0500
committerJethro Grassie <jtg@xtrabass.com>2019-01-30 13:37:45 -0500
commit123fc2a25afaebe89b94c9806eb05033e021d807 (patch)
tree2151ced1046c2b1e40c8c123fa60d2d38ba0df7f /contrib/epee
parentMerge pull request #4988 (diff)
downloadmonero-123fc2a25afaebe89b94c9806eb05033e021d807.tar.xz
i2p: initial support
Diffstat (limited to 'contrib/epee')
-rw-r--r--contrib/epee/include/net/net_utils_base.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/contrib/epee/include/net/net_utils_base.h b/contrib/epee/include/net/net_utils_base.h
index 82f8a7fe8..ffd106e10 100644
--- a/contrib/epee/include/net/net_utils_base.h
+++ b/contrib/epee/include/net/net_utils_base.h
@@ -47,6 +47,7 @@
namespace net
{
class tor_address;
+ class i2p_address;
}
namespace epee
@@ -196,7 +197,7 @@ namespace net_utils
template<typename Type> const Type &as() const { return as_mutable<const Type>(); }
BEGIN_KV_SERIALIZE_MAP()
// need to `#include "net/tor_address.h"` when serializing `network_address`
static constexpr std::integral_constant<bool, is_store> is_store_{};
std::uint8_t type = std::uint8_t(is_store ? this_ref.get_type_id() : address_type::invalid);
@@ -209,6 +210,8 @@ namespace net_utils
return this_ref.template serialize_addr<ipv4_network_address>(is_store_, stg, hparent_section);
case address_type::tor:
return this_ref.template serialize_addr<net::tor_address>(is_store_, stg, hparent_section);
+ case address_type::i2p:
+ return this_ref.template serialize_addr<net::i2p_address>(is_store_, stg, hparent_section);
case address_type::invalid:
default:
break;
@@ -196,7 +197,7 @@ namespace net_utils
template<typename Type> const Type &as() const { return as_mutable<const Type>(); }
BEGIN_KV_SERIALIZE_MAP()
- // need to `#include "net/tor_address.h"` when serializing `network_address`
+ // need to `#include "net/[i2p|tor]_address.h"` when serializing `network_address`
static constexpr std::integral_constant<bool, is_store> is_store_{};
std::uint8_t type = std::uint8_t(is_store ? this_ref.get_type_id() : address_type::invalid);